.. meta::
   :description: Gaitalytics is a Python library for easy gait-metrics for everyone.
   :keywords: gaitalytics, gait-analysis, mocap, c3d, gait-metrics, biomechanics, time-series, data-analysis, data, gait


.. image:: ./_static/images/Gaitalytics_noBackground.png
    :alt: Gaitalytics Logo
    :align: center
    :width: 200px

.. include:: ../README.rst


.. toctree::
   :maxdepth: 2
   :hidden:

   usage/index
   extend/index
   api
   reference/index
   contributing
   authors
   changelog



